@@ -85,9 +85,11 @@ class LVMTemplateForm(NetBoxModelForm):
     )
 
     class Meta:
-        model = LogicalVolume
+        model = MountedVolume
         fields = [
-            "lv_name"
+            "mountpoint",
+            "fs_type",
+            "fs_options"
         ]
 
     def save(self, *args, **kwargs):
@@ -106,26 +108,41 @@ class LVMTemplateForm(NetBoxModelForm):
         print(f"Partition Count: {new_partition_count}")
         print(f"Device Name: {device_name_prefix}")
         device_name = device_name_prefix + str(new_partition_count)
-        mounted_volume = MountedVolume.objects.create(mount_point=self.cleaned_data['mountpoint'],
-                                                      fs_type=self.cleaned_data['fs_type'],
-                                                      options=self.cleaned_data['fs_options'])
+        # mounted_volume = MountedVolume.objects.create(mount_point=self.cleaned_data['mountpoint'],
+        #                                               fs_type=self.cleaned_data['fs_type'],
+        #                                               options=self.cleaned_data['fs_options'])
+        # mounted_volume.save()
+        mounted_volume = super().save(*args, **kwargs)
+        print(f"Mounted Volume ID: {mounted_volume.id}")
 
         linux_device = LinuxDevice.objects.create(device=device_name, type='efi')
+        linux_device.save()
+        print(f"Linux Device ID: {linux_device.id}")
+
         partition = Partition.objects.create(drive=self.cleaned_data['drive'], device=linux_device,
                                              size=self.cleaned_data['size'], type='Linux LVM')
+        partition.save()
+        print(f"Partition ID: {partition.id}")
 
         volume_group = VolumeGroup.objects.create(vg_name=self.cleaned_data['vg_name'])
-        PhysicalVolume.objects.create(device=linux_device, vg=volume_group)
+        volume_group.save()
+        print(f"Volume Group ID: {volume_group.id}")
+
+        pv = PhysicalVolume.objects.create(device=linux_device, vg=volume_group)
+        pv.save()
+        print(f"Physical Volume ID: {pv.id}")
 
         # Add linux_device for lvm
         linux_device_mapper = LinuxDevice.objects.create(device='/dev/mapper/vg_system-lv_home',
-                                                         type=self.cleaned_data['fs_type'])
-        self.instance.vg = volume_group
-        self.instance.size = self.cleaned_data['size']
-        self.instance.device = linux_device_mapper
-        logical_volume = super().save(*args, **kwargs)
+                                                         type='efi')
+        linux_device_mapper.save()
+        print(f"Linux Device ID: {linux_device_mapper.id}")
 
-        return logical_volume
+        lv = LogicalVolume.objects.create(vg=volume_group, lv_name=self.cleaned_data['lv_name'],
+                                          size=self.cleaned_data['size'], device=linux_device_mapper)
+        lv.save()
+        print(f"{lv}")
+        return mounted_volume
 
 
 class DriveTemplateForm(NetBoxModelForm):
