@@ -59,11 +59,12 @@ class TemplateVolumeConfig(PluginTemplateExtension):
         print(f"Lonely Drives: {lonely_drive}")
         print(f"Partitions: {partitions}")
         print(f"drives: {drives_id}")
+
         return self.render(
             "netbox_storage/inc/template_box.html",
             extra_context={
                 "lonely_drives": lonely_drive,
-                "partitions": partitions
+                "partitions": partitions,
             }
         )
 
